Enum Syscall
Source pub enum Syscall {
Show 73 variants
Invalid = 0,
Exit = 1,
Clone = 2,
Execve = 3,
ExecveABI = 4,
Waitpid = 5,
Kill = 6,
Getpid = 7,
Getppid = 8,
Brk = 12,
Sbrk = 13,
Putchar = 16,
Getchar = 17,
Sleep = 20,
Yield = 21,
ExitGroup = 23,
SetTls = 30,
GetTls = 31,
SetTidAddress = 32,
RegisterAbiZone = 90,
UnregisterAbiZone = 91,
CreateNamespace = 92,
HandleQuery = 100,
HandleSetRole = 101,
HandleClose = 102,
HandleDuplicate = 103,
HandleControl = 110,
StreamRead = 200,
StreamWrite = 201,
FileSeek = 300,
FileTruncate = 301,
VfsOpen = 400,
VfsRemove = 401,
VfsCreateFile = 402,
VfsCreateDirectory = 403,
VfsChangeDirectory = 404,
VfsTruncate = 405,
VfsCreateSymlink = 406,
VfsReadlink = 407,
VfsGetCwdPath = 408,
FsMount = 500,
FsUmount = 501,
FsPivotRoot = 502,
Pipe = 600,
EventChannelCreate = 610,
EventSubscribe = 611,
EventUnsubscribe = 612,
EventPublish = 613,
EventHandlerRegister = 614,
EventSendDirect = 615,
SharedMemoryCreate = 620,
SharedMemoryResize = 621,
SocketSendHandle = 630,
SocketRecvHandle = 631,
SocketSendHandleAndData = 632,
SocketRecvHandleAndData = 633,
MemoryMap = 700,
MemoryUnmap = 701,
SocketCreate = 900,
SocketBind = 901,
SocketListen = 902,
SocketConnect = 903,
SocketAccept = 904,
Socketpair = 905,
SocketShutdown = 906,
SocketRecvFrom = 907,
SocketSendTo = 908,
NetworkSetIpv4 = 910,
NetworkSetGateway = 911,
NetworkSetDns = 912,
NetworkSetNetmask = 913,
NetworkListInterfaces = 914,
ProfilerDump = 999,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.